(***************************************************************************************************************)
(******                       This is the FeynRules mod-file for the Unbroken Standard model              ******)
(******                                                              with arbitrary coefficients          ******)
(******                                                                                                   ******)
(******     Authors: J. Santiago                                                                          ******)
(******                                                                                                   ******)
(****** Choose whether Feynman gauge is desired.                                                          ******)
(****** If set to False, unitary gauge is assumed.                                                          ****)
(****** Feynman gauge is especially useful for CalcHEP/CompHEP where the calculation is 10-100 times faster. ***)
(****** Feynman gauge is not supported in MadGraph and Sherpa.                                              ****)
(***************************************************************************************************************)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "L4 Standard Model with arbitrary coefficients";

M$Information = {
  Authors      -> {"J. Santiago"}, 
  Version      -> "1.0",
  Date         -> "18. 11. 2016",
  Institutions -> {"CAFPE and Universidad de Granada"},
  Emails       -> {"jsantiago@ugr.es"}
};

FeynmanGauge = True;



(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {

  (* External parameters *)

  (* Internal Parameters *)
  
  alphaSM1 == {
    ParameterType -> Internal
  },

  alphaSM2 == {
    ParameterType -> Internal
  },

  alphaSM3 == {
    ParameterType -> Internal
  },

  alphaSM4 == {
    ParameterType -> Internal,
    Indices          -> {Index[Generation], Index[Generation]},
    Hermitian -> True
  },

  alphaSM5 == {
    ParameterType -> Internal,
    Indices          -> {Index[Generation], Index[Generation]},
    Hermitian -> True
  },

  alphaSM6 == {
    ParameterType -> Internal,
    Indices          -> {Index[Generation], Index[Generation]},
    Hermitian -> True
  },

  alphaSM7 == {
    ParameterType -> Internal,
    Indices          -> {Index[Generation], Index[Generation]},
    Hermitian -> True
  },

  alphaSM8 == {
    ParameterType -> Internal,
    Indices          -> {Index[Generation], Index[Generation]},
    Hermitian -> True
  },

  alphaSM9 == {
    ParameterType -> Internal
  },

  alphaSM10 == {
    ParameterType -> Internal
  },

  alphaSM11 == {
    ParameterType -> Internal
  },

  alphaSM12 == {
    ParameterType -> Internal,
    Indices          -> {Index[Generation], Index[Generation]}
  },

  alphaSM13 == {
    ParameterType -> Internal,
    Indices          -> {Index[Generation], Index[Generation]}
  },

  alphaSM14 == {
    ParameterType -> Internal,
    Indices          -> {Index[Generation], Index[Generation]}
  },

  alphaSM15 == {
    ParameterType -> Internal
  },

  alphaSM16 == {
    ParameterType -> Internal
  },

  alphaSM17 == {
    ParameterType -> Internal
  }

};


(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)



L4Gauge := Block[{mu,nu,ii,aa}, 
  ExpandIndices[-1/4 alphaSM1 FS[B,mu,nu] FS[B,mu,nu] - 1/4 alphaSM2 FS[Wi,mu,nu,ii] FS[Wi,mu,nu,ii] - 1/4 alphaSM3 FS[G,mu,nu,aa] FS[G,mu,nu,aa], FlavorExpand->SU2W]];

L4Fermions := Block[{mu,sp1,sp2,ff1,ff2,cc,ii}, 
  ExpandIndices[I*(
     alphaSM4[ff1,ff2] Ga[mu,sp1,sp2] QLbar[sp1,ii,ff1,cc].DC[QL[sp2,ii,ff2,cc], mu] 
    +alphaSM5[ff1,ff2] Ga[mu,sp1,sp2] LLbar[sp1,ii,ff1].DC[LL[sp2,ii,ff2], mu] 
    +alphaSM6[ff1,ff2] Ga[mu,sp1,sp2] URbar[sp1,ff1,cc].DC[UR[sp2,ff2,cc], mu] 
    +alphaSM7[ff1,ff2] Ga[mu,sp1,sp2] DRbar[sp1,ff1,cc].DC[DR[sp2,ff2,cc], mu] 
    +alphaSM8[ff1,ff2] Ga[mu,sp1,sp2] LRbar[sp1,ff1].DC[LR[sp2,ff2], mu]), 
  FlavorExpand->{SU2W,SU2D}]];



L4Higgs := Block[{ii,mu, feynmangaugerules},
  feynmangaugerules = If[Not[FeynmanGauge], {G0|GP|GPbar ->0}, {}]; 
  ExpandIndices[alphaSM9 DC[Phibar[ii],mu] DC[Phi[ii],mu] +alphaSM10 Phibar[ii] Phi[ii] -alphaSM11 Phibar[ii] Phi[ii] Phibar[jj] Phi[jj], FlavorExpand->{SU2D,SU2W}]/.feynmangaugerules 
 ]; 

L4Yukawa := Block[{sp,ii,jj,cc,ff1,ff2,ff3,yuk,feynmangaugerules},
  feynmangaugerules = If[Not[FeynmanGauge], {G0|GP|GPbar ->0}, {}];
 
  yuk = ExpandIndices[
   -alphaSM12[ff1,ff2] QLbar[sp, ii, ff1, cc].DR [sp, ff2, cc] Phi[ii] - 
    alphaSM13[ff1,ff2] LLbar[sp, ii, ff1].LR [sp, ff2] Phi[ii] - 
    alphaSM14[ff1,ff2] QLbar[sp, ii, ff1, cc].UR [sp, ff2, cc] Phibar[jj] Eps[ii, jj], FlavorExpand -> SU2D];
  yuk+HC[yuk]/.feynmangaugerules
 ];


L4Ghost := Block[{LGh1,LGhw,LGhs,LGhphi,mu, generators,gh,ghbar,Vectorize,phi1,phi2,togoldstones,doublet,doublet0},
  (* Pure gauge piece *) 	
  LGh1 = -alphaSM15 ghBbar.del[DC[ghB,mu],mu];
  LGhw = -alphaSM16 ghWibar.del[DC[ghWi,mu],mu];
  LGhs = -alphaSM17 ghGbar.del[DC[ghG,mu],mu];


ExpandIndices[ LGhs + LGh1 + LGhw , FlavorExpand->SU2W]];

Ltot:= L4Gauge + L4Fermions + L4Higgs + L4Yukawa + L4Ghost;


