(***************************************************************************************************************)
(******                       This is the FeynRules mod-file for the Unbroken Standard model              ******)
(******                                                                                                   ******)
(******     Authors: J. Santiago                                                                          ******)
(******                                                                                                   ******)
(****** Choose whether Feynman gauge is desired.                                                          ******)
(****** If set to False, unitary gauge is assumed.                                                          ****)
(****** Feynman gauge is especially useful for CalcHEP/CompHEP where the calculation is 10-100 times faster. ***)
(****** Feynman gauge is not supported in MadGraph and Sherpa.                                              ****)
(***************************************************************************************************************)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "Dimension 6 SM Effective Lagrangian";

M$Information = {
  Authors      -> {"J. Santiago"}, 
  Version      -> "1.0",
  Date         -> "2. 04. 2015",
  Institutions -> {"CAFPE and Universidad de Granada"},
  Emails       -> {"jsantiago@ugr.es"}
};

FeynmanGauge = True;


(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {

  (* External parameters *)

  (* Internal Parameters *)

  	 
  alphaO1 == { 
    ParameterType    -> Internal
  },

  alphaO2 == { 
    ParameterType    -> Internal
  },
  	 
  alphaR1 == { 
    ParameterType    -> Internal,
    ComplexParameter -> True
  },
  	 
  alphaO3 == { 
    ParameterType    -> Internal
  },
  	 
  alphaO4 == { 
    ParameterType    -> Internal
  },
  alphaO5 == { 
    ParameterType    -> Internal
  },
  alphaO6 == { 
    ParameterType    -> Internal
  },
  alphaO7 == { 
    ParameterType    -> Internal
  },
  alphaO8 == { 
    ParameterType    -> Internal
  },
  alphaO9 == { 
    ParameterType    -> Internal
  },
  alphaO10 == { 
    ParameterType    -> Internal
  },
  alphaO11 == { 
    ParameterType    -> Internal
  },
  alphaR2 == { 
    ParameterType    -> Internal
  },
  alphaR3 == { 
    ParameterType    -> Internal
  },
  alphaR4 == { 
    ParameterType    -> Internal
  },
  alphaO12 == { 
    ParameterType    -> Internal
  },
  alphaO13 == { 
    ParameterType    -> Internal
  },
  alphaO14 == { 
    ParameterType    -> Internal
  },
  alphaO15 == { 
    ParameterType    -> Internal
  },
  alphaR5 == { 
    ParameterType    -> Internal
  },
  alphaR6 == { 
    ParameterType    -> Internal
  },
  alphaR7 == { 
    ParameterType    -> Internal
  }
};


(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)

(* Recall that Ta=sigma/2 *)
(* We have a change of notation wrt HEL *)
Wvec[mu_,nu_,ii_,jj_]:= Module[{aa},2 Ta[aa,ii,jj] FS[Wi,mu,nu,aa]];


LD2S4 := Block[{ii,jj,mu,hermilag,nonhermilag},
      hermilag=
		alphaO1 DC[Phibar[ii],mu] Phi[ii]  Phibar[jj] DC[Phi[jj],mu]
  	       +alphaO2 Phibar[ii] Phi[ii] del[del[Phibar[jj] Phi[jj],mu],mu];
      nonhermilag=
               alphaR1 Phibar[ii] Phi[ii] Phibar[jj] DC[DC[Phi[jj],mu],mu];

  ExpandIndices[
               hermilag+nonhermilag+HC[nonhermilag]
               , FlavorExpand->{SU2D,SU2W}]
];


LS6 := Block[{ii,jj,kk}, alphaO3 Phibar[ii] Phi[ii] Phibar[jj] Phi[jj] Phibar[kk] Phi[kk]];

LD4S2 := Block[{ii,jj,aa,mu,nu,ro,sig},
  ExpandIndices[
                alphaR2 Phibar[ii] DC[DC[DC[DC[Phi[ii],mu],mu],nu],nu]
	       +I alphaR3 (Phibar[ii] DC[Phi[ii],nu]- DC[Phibar[ii],nu] Phi[ii]) del[FS[B,mu,nu],mu]
	       +I alphaR4 (Phibar[ii]  DC[Phi[jj],nu]-DC[Phibar[ii],nu] Phi[jj]) DC[Wvec[mu,nu,ii,jj],mu]
               +alphaO4 Phibar[ii] Phi[ii] FS[G,mu,nu,jj] FS[G,mu,nu,jj]
               +alphaO5 1/2 Eps[mu,nu,ro,sig] Phibar[ii] Phi[ii] FS[G,mu,nu,aa] FS[G,ro,sig,aa]
               +alphaO6 Phibar[ii] Phi[ii] FS[Wi,mu,nu,jj] FS[Wi,mu,nu,jj]
               +alphaO7 1/2 Eps[mu,nu,ro,sig] Phibar[ii] Phi[ii] FS[Wi,mu,nu,aa] FS[Wi,ro,sig,aa]
               +alphaO8 Phibar[ii] Phi[ii] FS[B,mu,nu] FS[B,mu,nu]
               +alphaO9 1/2 Eps[mu,nu,ro,sig] Phibar[ii] Phi[ii] FS[B,mu,nu] FS[B,ro,sig]
               +alphaO10 Phibar[ii] Phi[jj] Wvec[mu,nu,ii,jj] FS[B,mu,nu]
               +alphaO11 1/2 Eps[mu,nu,ro,sig] Phibar[ii] Phi[jj] Wvec[mu,nu,ii,jj] FS[B,ro,sig]
               , FlavorExpand->{SU2D,SU2W}]
];


LD6G := Block[{ii,jj,kk,mu,nu,ro,alp,bet},
  alphaR5 DC[FS[G,mu,nu,ii],mu] DC[FS[G,ro,nu,ii],ro]
 +alphaO12 FSU3C[ii,jj,kk] FS[G,mu,nu,ii] FS[G,nu,ro,jj] FS[G,ro,mu,kk]
 +alphaO13 1/2 Eps[mu,nu,alp,bet] FSU3C[ii,jj,kk] FS[G,alp,bet,ii] FS[G,nu,ro,jj] FS[G,ro,mu,kk]
];


LD6W := Block[{ii,jj,kk,mu,nu,ro,alp,bet},
 +alphaR6 ExpandIndices[ DC[FS[Wi,mu,nu,ii],mu] DC[FS[Wi,ro,nu,ii],ro], FlavorExpand->{SU2D,SU2W}]
 +alphaO14 ExpandIndices[FSU2L[ii,jj,kk] FS[Wi,mu,nu,ii] FS[Wi,nu,ro,jj] FS[Wi,ro,mu,kk], FlavorExpand->{SU2D,SU2W}]
 +alphaO15 ExpandIndices[1/2 Eps[mu,nu,alp,bet] FSU2L[ii,jj,kk] FS[Wi,alp,bet,ii] FS[Wi,nu,ro,jj] FS[Wi,ro,mu,kk], FlavorExpand->{SU2D,SU2W}]
];



LD6B := Block[{ii,jj,kk,mu,nu,ro,alp,bet},
 +alphaR7 ExpandIndices[ del[FS[B,mu,nu],mu] del[FS[B,ro,nu],ro], FlavorExpand->{SU2D,SU2W}]
];

Ltot:= LD2S4+LS6+LD4S2+LD6G+LD6W+LD6B;


