(***************************************************************************************************************)
(******                       This is the FeynRules mod-file for the Unbroken Standard model              ******)
(******                                                                                                   ******)
(******     Authors: J. Santiago, A. Carmona                                                              ******)
(******                                                                                                   ******)
(****** Choose whether Feynman gauge is desired.                                                          ******)
(****** If set to False, unitary gauge is assumed.                                                          ****)
(****** Feynman gauge is especially useful for CalcHEP/CompHEP where the calculation is 10-100 times faster. ***)
(****** Feynman gauge is not supported in MadGraph and Sherpa.                                              ****)
(***************************************************************************************************************)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "Dimension 6 SM Effective Lagrangian, 4 Fermions (bar{L} L) (bar{R}R)";

M$Information = {
  Authors      -> {"A. Carmona,J. Santiago"}, 
  Version      -> "1.0",
  Date         -> "10. 08. 2016",
  Institutions -> {"CERN, CAFPE and Universidad de Granada"},
  Emails       -> {"adrian.carmona@cern.ch,jsantiago@ugr.es"}
};

FeynmanGauge = True;


(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {

  (* External parameters *)

  (* Internal Parameters *)

  	 
  alphaO35 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaO36 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaO37 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaO38 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaO39 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaO40 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaO41 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaO42 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },

  alphaR62 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaR63 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaR64 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaR65 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE32 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE33 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE34 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE35 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE36 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE37 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE38 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE39 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE40 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE41 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE42 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE43 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE44 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaE45 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  }  	 

};


(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)

(* Recall that Ta=sigma/2 *)
(* Define sigma[mu,nu]= I/2 [gamma(mu),gamma(nu)] *)
sigmamunu[mu_,nu_,sp_,sp2_]:=Module[{sp1},(I/2)*(Ga[mu,sp,sp1]*Ga[nu,sp1,sp2]-Ga[nu,sp,sp1]*Ga[mu,sp1,sp2])];
gamma3[mu_,nu_,rho_,sp1_,sp4_]:=Module[{sp2,sp3},Ga[mu,sp1,sp2]*Ga[nu,sp2,sp3]*Ga[rho,sp3,sp4]];

LF4LLRR := Block[{lag,lagnoh,ff1,ff2,ff3,ff4,sp1,sp2,sp3,sp4,jj,cc1,cc2,cc3,cc4,aa,mu,nu,rho},
      lag= ExpandIndices[
           alphaO35[ff1,ff2,ff3,ff4]*(LLbar[sp1,jj,ff1].LL[sp2,jj,ff2])*(LRbar[sp3,ff3].LR[sp4,ff4])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaO36[ff1,ff2,ff3,ff4]*(LLbar[sp1,jj,ff1].LL[sp2,jj,ff2])*(URbar[sp3,ff3,cc1].UR[sp4,ff4,cc1])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaO37[ff1,ff2,ff3,ff4]*(LLbar[sp1,jj,ff1].LL[sp2,jj,ff2])*(DRbar[sp3,ff3,cc1].DR[sp4,ff4,cc1])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaO38[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc1])*(LRbar[sp3,ff3].LR[sp4,ff4])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaO39[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc1])*(URbar[sp3,ff3,cc2].UR[sp4,ff4,cc2])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaO40[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(URbar[sp3,ff3,cc3].UR[sp4,ff4,cc4])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]*(2*T[aa,cc1,cc2])*(2*T[aa,cc3,cc4])
          +alphaO41[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc1])*(DRbar[sp3,ff3,cc2].DR[sp4,ff4,cc2])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaO42[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(DRbar[sp3,ff3,cc3].DR[sp4,ff4,cc4])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]*(2*T[aa,cc1,cc2])*(2*T[aa,cc3,cc4])
          +alphaR62[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(URbar[sp3,ff3,cc2].UR[sp4,ff4,cc1])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaR63[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(URbar[sp3,ff3,cc3].UR[sp4,ff4,cc4])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]*(2*T[aa,cc1,cc4])*(2*T[aa,cc3,cc2])
          +alphaR64[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(DRbar[sp3,ff3,cc2].DR[sp4,ff4,cc1])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaR65[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(DRbar[sp3,ff3,cc3].DR[sp4,ff4,cc4])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]*(2*T[aa,cc1,cc4])*(2*T[aa,cc3,cc2])
          +alphaE33[ff1,ff2,ff3,ff4]*(LLbar[sp1,jj,ff1].LL[sp2,jj,ff2])*(LRbar[sp3,ff3].LR[sp4,ff4])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaE34[ff1,ff2,ff3,ff4]*(LLbar[sp1,jj,ff1].LL[sp2,jj,ff2])*(URbar[sp3,ff3,cc1].UR[sp4,ff4,cc1])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaE35[ff1,ff2,ff3,ff4]*(LLbar[sp1,jj,ff1].LL[sp2,jj,ff2])*(DRbar[sp3,ff3,cc1].DR[sp4,ff4,cc1])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaE36[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc1])*(LRbar[sp3,ff3].LR[sp4,ff4])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaE37[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc1])*(URbar[sp3,ff3,cc2].UR[sp4,ff4,cc2])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaE38[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(URbar[sp3,ff3,cc3].UR[sp4,ff4,cc4])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]*(2*T[aa,cc1,cc2])*(2*T[aa,cc3,cc4])
          +alphaE39[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc1])*(DRbar[sp3,ff3,cc2].DR[sp4,ff4,cc2])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaE40[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(DRbar[sp3,ff3,cc3].DR[sp4,ff4,cc4])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]*(2*T[aa,cc1,cc2])*(2*T[aa,cc3,cc4])
          +alphaE41[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(URbar[sp3,ff3,cc2].UR[sp4,ff4,cc1])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaE42[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(URbar[sp3,ff3,cc3].UR[sp4,ff4,cc4])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]*(2*T[aa,cc1,cc4])*(2*T[aa,cc3,cc2])
          +alphaE43[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(DRbar[sp3,ff3,cc2].DR[sp4,ff4,cc1])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaE44[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(DRbar[sp3,ff3,cc3].DR[sp4,ff4,cc4])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]*(2*T[aa,cc1,cc4])*(2*T[aa,cc3,cc2])
          ,FlavorExpand->SU2D];
      lagnoh= ExpandIndices[
           alphaE32[ff1,ff2,ff3,ff4]*(LLbar[sp1,jj,ff1].QL[sp2,jj,ff2,cc1])*(DRbar[sp3,ff3,cc1].LR[sp4,ff4])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaE45[ff1,ff2,ff3,ff4]*(LLbar[sp1,jj,ff1].QL[sp2,jj,ff2,cc1])*(DRbar[sp3,ff3,cc1].LR[sp4,ff4])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          ,FlavorExpand->SU2D];
	  lag+lagnoh+HC[lagnoh]
];



Ltot:= LF4LLRR;

