(***************************************************************************************************************)
(******                       This is the FeynRules mod-file for the Unbroken Standard model              ******)
(******                                                                                                   ******)
(******     Authors: J. Santiago, A. Carmona                                                              ******)
(******                                                                                                   ******)
(****** Choose whether Feynman gauge is desired.                                                          ******)
(****** If set to False, unitary gauge is assumed.                                                          ****)
(****** Feynman gauge is especially useful for CalcHEP/CompHEP where the calculation is 10-100 times faster. ***)
(****** Feynman gauge is not supported in MadGraph and Sherpa.                                              ****)
(***************************************************************************************************************)

(* ************************** *)
(* *****  Information   ***** *)
(* ************************** *)
M$ModelName = "Dimension 6 SM Effective Lagrangian, 4 Fermions (bar{L} L) (bar{R}R)";

M$Information = {
  Authors      -> {"A. Carmona,J. Santiago"}, 
  Version      -> "1.0",
  Date         -> "10. 08. 2016",
  Institutions -> {"CERN, CAFPE and Universidad de Granada"},
  Emails       -> {"adrian.carmona@cern.ch,jsantiago@ugr.es"}
};

FeynmanGauge = True;


(* ************************** *)
(* *****   Parameters   ***** *)
(* ************************** *)
M$Parameters = {

  (* External parameters *)

  (* Internal Parameters *)

  	 
  alphaA1 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaA2 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaA3 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaA4 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  
  alphaA5 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaA6 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaA7 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  },
  	 
  alphaA8 == { 
    ParameterType    -> Internal,
    Indices          -> {Index[Generation],Index[Generation],Index[Generation],Index[Generation]}
  }  	 
  	 

};


(* ************************** *)
(* *****   Lagrangian   ***** *)
(* ************************** *)

(* Recall that Ta=sigma/2 *)
(* Define sigma[mu,nu]= I/2 [gamma(mu),gamma(nu)] *)
sigmamunu[mu_,nu_,sp_,sp2_]:=Module[{sp1},(I/2)*(Ga[mu,sp,sp1]*Ga[nu,sp1,sp2]-Ga[nu,sp,sp1]*Ga[mu,sp1,sp2])];
gamma3[mu_,nu_,rho_,sp1_,sp4_]:=Module[{sp2,sp3},Ga[mu,sp1,sp2]*Ga[nu,sp2,sp3]*Ga[rho,sp3,sp4]];

LF4LbarLRbarR := Block[{lag,lagnoh,ff1,ff2,ff3,ff4,sp1,sp2,sp3,sp4,jj,cc1,cc2,cc3,cc4,aa,mu,nu,rho},
      lag= ExpandIndices[
           alphaA1[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc1])*(URbar[sp3,ff3,cc2].UR[sp4,ff4,cc2])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]
          +alphaA2[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(URbar[sp3,ff3,cc3].UR[sp4,ff4,cc4])*Ga[mu,sp1,sp2]*Ga[mu,sp3,sp4]*(2*T[aa,cc1,cc2])*(2*T[aa,cc3,cc4])
          +alphaA3[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].UR[sp1,ff4,cc1])*(URbar[sp2,ff3,cc2].QL[sp2,jj,ff2,cc2])
          +alphaA4[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].UR[sp1,ff4,cc2])*(URbar[sp2,ff3,cc3].QL[sp2,jj,ff2,cc4])*(2*T[aa,cc1,cc2])*(2*T[aa,cc3,cc4])
          +alphaA5[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc1])*(URbar[sp3,ff3,cc2].UR[sp4,ff4,cc2])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]
          +alphaA6[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].QL[sp2,jj,ff2,cc2])*(URbar[sp3,ff3,cc3].UR[sp4,ff4,cc4])*gamma3[mu,nu,rho,sp1,sp2]*gamma3[mu,nu,rho,sp3,sp4]*(2*T[aa,cc1,cc2])*(2*T[aa,cc3,cc4])
          +alphaA7[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].UR[sp2,ff4,cc1])*(URbar[sp3,ff3,cc2].QL[sp4,jj,ff2,cc2])*sigmamunu[mu,nu,sp1,sp2]*sigmamunu[mu,nu,sp3,sp4]
          +alphaA8[ff1,ff2,ff3,ff4]*(QLbar[sp1,jj,ff1,cc1].UR[sp2,ff4,cc2])*(URbar[sp3,ff3,cc3].QL[sp4,jj,ff2,cc4])*(2*T[aa,cc1,cc2])*(2*T[aa,cc3,cc4])*sigmamunu[mu,nu,sp1,sp2]*sigmamunu[mu,nu,sp3,sp4]
          ,FlavorExpand->SU2D];
	  lag
];



Ltot:= LF4LbarLRbarR;

