#!/usr/bin/env python2

import file as jsf
import subprocess
import glob
import os
import sys


# This will be used to replace the correct spatial indices
def JSP_replace(st,ilist,plist):
    repl=[('[','('),(']',')')]
    for x in ['i','y','mu','nu','w','a','al','be','ro','si']:
        repl.extend([(x+x+str(i+1),x+str(t)) for (i,t) in enumerate(ilist)])
    repl.extend([('pp'+str(i+1),t) for (i,t) in enumerate(plist)])
    #print repl
    return  reduce(lambda a, kv: a.replace(*kv), repl, st)


def allpos(i):
    res=int(i)
    if res<0:
        res += 100
    return str(res)

def feynman_rules(dirname):
    # This is a dictionary of dictionaries encoding all the Feynman rules
    alldicts={}
    templist=glob.glob(dirname+"QGRAF/model_data/*list")
    allkeys=[x.split('/')[-1][:-4] for x in templist]
    for key in allkeys:
        filename=dirname+"QGRAF/model_data/"+key+"list"
        tempdict={}
        for line in open(filename):
            tempdict[" ".join(line.split()[:-1])]=line.split()[-1]
        alldicts[key]=tempdict
    return alldicts


def read_new_symbols(dirname):
    # define new symbols
    with open(dirname+'QGRAF/model_data/newsymbols') as f:
        lines = f.read().splitlines()
    newsymbols=", ".join([x.strip() for x in lines])
    return newsymbols

def read_new_functions(dirname):
    # define new functions
    with open(dirname+'QGRAF/model_data/newfunctions') as f:
        lines = f.read().splitlines()
    newfunctions=", ".join([x.strip() for x in lines])
    return newfunctions

def read_partial_fractions(dirname):
    # define new partial fractions
    with open(dirname+'QGRAF/model_data/listmass') as f:
        lines = f.read().splitlines()
    partialfrac=''
    if len(lines)>0:
        masslist=(lines[0].split())
        for x in [(masslist[i],masslist[j]) for i in range(len(masslist)) for j in range(i+1, len(masslist))]:
            partialfrac += "repeat;\n" 
            partialfrac += "id,once prop(k1, "+x[0]+")*prop(k1, "+x[1]+")= 1/("+x[0]+"^2-"+x[1]+"^2)*(prop(k1, "+x[0]+")- prop(k1, "+x[1]+"));\n" 
            partialfrac += "endrepeat;\n\n" 
    return partialfrac


def write_aux_files(dirname,filename,alldicts):
    process=filename.split('/')[-1][:-4]
    particles=process.split('_')
    bosons=['G','W1','W2','W3','B','H1','H1bar','H2','H2bar']
    bparticles=[x for x in particles if x in bosons]
    dim=(3*len(particles)-len(bparticles))/2
    thenmax=6-dim
    print "parts=",particles
    print "numparts=",len(particles)," dim=",dim,"  thenmax=",thenmax
    looporder=filename.split('/')[-2]
    formdir=dirname+'FORM/'+looporder+'/'
    print "Doing file",filename,"that corresponds to process",process,"at",looporder
    print
    if not os.path.isdir(formdir):
        subprocess.call("mkdir "+formdir,shell=True)

    diagnum=1
    lastline=0
    outputline=''

    outputfilename=formdir+process+'.aux' # one diagram at a time

    if os.path.isfile(outputfilename+"tralalala"):
        print "diagram file",outputfilename,"os present"
        print "delete it if you want to regenerate the diagrams"
        diagnum=int(subprocess.check_output(" tail -n 2 "+outputfilename,shell=True).split()[1].replace("diags",""))+1
        print "number of diagrams generated=", diagnum-1
    else:
        of = open(outputfilename,"w")
        for line in open(filename): 
            datalinetemp=line.rstrip().replace('(',',').replace(')','').replace('*','').split(',')
            if datalinetemp[-1]=='' and len(datalinetemp)>1: 
                # last line of the current diagram
                lastline=1
                dataline=datalinetemp[:-1]
            else:
                dataline=datalinetemp

            # Now we start with the proper replacements
            if dataline[0]=='' and len(dataline)>1:
                # numerical factor
                outputline += "("+dataline[1].replace("+","")+")"        
            elif len(dataline)>1: 
                [op,fields,indices0,ppi]=dataline[0].strip(),dataline[1::3],dataline[2::3],dataline[3::3]
                indices = [allpos(ii) for ii in indices0]
                outputline += "*("+JSP_replace(alldicts[op][" ".join(fields)],indices,ppi)+")"

            if lastline==1:
                #print "id diags"+str(diagnum)+" = "+outputline+";\n"
                of.write("id diags"+str(diagnum)+" = "+outputline+";\n\n")
                diagnum += 1
                outputline=''
                lastline = 0

        of.close()
    return diagnum,process,thenmax,formdir


def generate_form(dirname0):
    if os.path.isdir(dirname0):
        if "/" not in dirname0[-1]:
            dirname = dirname0+"/"
        else:
            dirname = dirname0
        print "doing directory",dirname


        alldicts=feynman_rules(dirname)
        newsymbols=read_new_symbols(dirname)
        newfunctions=read_new_functions(dirname)
        partialfrac=read_partial_fractions(dirname)
        # Go through all the QGRAF files
        filelist=glob.glob(dirname+"QGRAF/proc*/*qgf")
        print filelist

        for filename in filelist:
            diagnum,process,thenmax,formdir=write_aux_files(dirname,filename,alldicts)
            ## Let's now write the form skeleton program

            myrepl= ('NUMBER_OF_DIAGRAMS',str(diagnum-1)),('NEW_SYMBOLS',newsymbols),('NEW_FUNCTIONS',newfunctions),("FILE_WITH_DIAGRAMS",process+".aux"),("PROCESS",process.replace("_","").replace("[","").replace("]","")),("PARTIALFRACTIONS",partialfrac),("THENMAX",str(thenmax))
            jsf.dress_skeleton(myrepl,'skeleton.frm',formdir+process+'.frm')
    else:
        print "not a valid directory"

if __name__=='__main__':

    generate_form(sys.argv[1])


